aboutsummaryrefslogtreecommitdiff
path: root/engines/tsage/scenes.cpp
diff options
context:
space:
mode:
authorPaul Gilbert2011-10-25 21:00:41 +1100
committerPaul Gilbert2011-10-26 20:13:06 +1100
commite93c847df76b87cbed8201f68feeba9fd258999d (patch)
tree96c52d00cee5f7f2f355c7b4c9a446401c38c4b0 /engines/tsage/scenes.cpp
parent9ccb2eea32e4b85394295f4eed9884f05bf75c08 (diff)
downloadscummvm-rg350-e93c847df76b87cbed8201f68feeba9fd258999d.tar.gz
scummvm-rg350-e93c847df76b87cbed8201f68feeba9fd258999d.tar.bz2
scummvm-rg350-e93c847df76b87cbed8201f68feeba9fd258999d.zip
TSAGE: Expanded a lot of game Id checks for Blue Force to include Ringworld 2 as well
Diffstat (limited to 'engines/tsage/scenes.cpp')
-rw-r--r--engines/tsage/scenes.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/engines/tsage/scenes.cpp b/engines/tsage/scenes.cpp
index 686b8725f5..5ed7c06800 100644
--- a/engines/tsage/scenes.cpp
+++ b/engines/tsage/scenes.cpp
@@ -456,8 +456,9 @@ void Scene::refreshBackground(int xAmount, int yAmount) {
(xSectionSrc + 1) * 160, (ySectionSrc + 1) * 100);
Rect destBounds(xSectionDest * 160, ySectionDest * 100,
(xSectionDest + 1) * 160, (ySectionDest + 1) * 100);
- if (g_vm->getGameID() == GType_BlueForce) {
- // For Blue Force, if the scene has an interface area, exclude it from the copy
+ if (g_vm->getGameID() != GType_Ringworld) {
+ // For Blue Force and Return to Ringworld, if the scene has an interface area,
+ // exclude it from the copy
srcBounds.bottom = MIN<int16>(srcBounds.bottom, BF_GLOBALS._interfaceY);
destBounds.bottom = MIN<int16>(destBounds.bottom, BF_GLOBALS._interfaceY);
}